@@ -26,40 +26,31 @@ type ocamldep =
 
 type input = Ocamldep of ocamldep | Input_file of string | Stdin
 
+type file_output_type = Source | Byte | Opt
+
+type sorting_strategy = Sort_ml | Sort_ml_mli
+
 type t = 
     { input : input;
-      files : string list;
-      sort_mli : bool }
+      filenames : string list;
+      files : Files.file_type list;
+      sort_strat : sorting_strategy;
+      output : file_output_type }
 
-let to_sort_mli param =
-  param.sort_mli
-
-let to_change_extension param =
-  if to_sort_mli param then
-    Files.change_cmo_cmi_extension
-  else
-    Files.change_cmo_extension
-
-let to_input_param param =
-  param.input
-
-let to_path input_param =
-  input_param.path
-
-let to_load_path input_param =
-  String.concat " -I " input_param.load_path
+let to_sorting_strategy param = param.sort_strat
+let to_input_param param = param.input
+let to_filenames param = param.filenames
+let to_files param = param.files
+let to_file_output_type param = param.output
 
+let to_path input_param = input_param.path
+let to_load_path input_param = String.concat " -I " input_param.load_path
 let to_preprocesor input_param =
   match input_param.preprocessor with
     | Some p -> "-pp " ^ p
     | None -> ""
-
-let to_files param =
-  param.files
-
-let to_concatened_files param =
-  String.concat " " (to_files param)
-
+let to_concatened_filenames param =
+  String.concat " " (to_filenames param)
 
 let to_command_line param =
   match param.input with
@@ -68,7 +59,7 @@ let to_command_line param =
 	(to_path input_param)
 	(to_load_path input_param)
 	(to_preprocesor input_param)
-	(to_concatened_files param)
+	(to_concatened_filenames param)
     | _ -> failwith "to_command_line"
 
 let to_stream param = 
@@ -85,6 +76,12 @@ let to_stream param =
     | Stdin ->
 	Stream.of_channel stdin
 
+let filename_of_file param =
+  match to_file_output_type param with
+      Source -> Files.source_filename_of_file
+    | Byte -> Files.byte_filename_of_file
+    | Opt -> Files.opt_filename_of_file
+
 let new_file_input_param file =
   Input_file file
     
@@ -94,7 +91,9 @@ let new_ocamldep_input_param path load_path preprocessor =
 		   preprocessor = preprocessor } in
     Ocamldep ocamldep
   
-let new_param input_param files sort_mli =
+let new_param input_param filenames sort_strat output =
   { input = input_param;
-    files = files;
-    sort_mli = sort_mli }
+    filenames = filenames;
+    files = List.map Files.file_of_filename filenames;
+    sort_strat = sort_strat;
+    output = output; }
